##  Template Elements at a Glance
When you open a template in the editor, the base fact sheet type appears by default. The base fact sheet type is the starting point for all relations and cannot be removed.
In a diagram template, you can configure these element types:
  * Base fact sheet type: Defines which fact sheets the template is centered around, for example, applications or business capabilities.
  * Drill‑down relations: Show expandable structures such as parent–child or “contains” relations.
Learn how to configure them in [Adding Drill‑Downs to a Template](https://help.sap.com/docs/leanix/ea/creating-and-editing-diagram-templates?locale=en-US&state=PRODUCTION&version=CLOUD#loiodc871529cf1046a4abcf4f183c9b6985__Adding-Drill-Downs-to-a-Template).
  * Dependency relations: Show peer‑level connections between fact sheets, such as application depends on interface.
Learn how to configure them in [Adding Dependencies to a Template](https://help.sap.com/docs/leanix/ea/creating-and-editing-diagram-templates?locale=en-US&state=PRODUCTION&version=CLOUD#loiodc871529cf1046a4abcf4f183c9b6985__Adding-Dependencies-to-a-Template).


If you start from a preset, some dependency relations or drill-downs may already be included. You can remove or extend them to fit your requirements.
